@@ -1,29 +1,36 @@
 
-from breathe.finder.core import FinderFactory, NoMatchesError
-from breathe.parser import DoxygenParserFactory, CacheFactory
-from breathe.renderer.rst.doxygen import DoxygenToRstRendererFactoryCreatorConstructor, \
-    RstContentCreator
-from breathe.renderer.rst.doxygen.domain import DomainHandlerFactoryCreator, NullDomainHandler
-from breathe.renderer.rst.doxygen.domain import CppDomainHelper, CDomainHelper
-from breathe.renderer.rst.doxygen.filter import FilterFactory, GlobFactory
-from breathe.renderer.rst.doxygen.target import TargetHandlerFactory
-from breathe.finder.doxygen.core import DoxygenItemFinderFactoryCreator
-from breathe.finder.doxygen.matcher import ItemMatcherFactory
-from breathe.directive.base import BaseDirective, DoxygenBaseDirective
-from breathe.directive.index import DoxygenIndexDirective, AutoDoxygenIndexDirective
-from breathe.directive.file import DoxygenFileDirective, AutoDoxygenFileDirective
-from breathe.process import AutoDoxygenProcessHandle
-from breathe.exception import BreatheError
-from breathe.project import ProjectInfoFactory, ProjectError
+from .finder.core import FinderFactory, NoMatchesError
+from .parser import DoxygenParserFactory, CacheFactory
+from .renderer.rst.doxygen import DoxygenToRstRendererFactoryCreatorConstructor, \
+    RstContentCreator, RenderContext
+from .renderer.rst.doxygen.domain import DomainHandlerFactoryCreator, NullDomainHandler
+from .renderer.rst.doxygen.domain import CppDomainHelper, CDomainHelper
+from .renderer.rst.doxygen.filter import FilterFactory, GlobFactory
+from .renderer.rst.doxygen.target import TargetHandlerFactory
+from .renderer.rst.doxygen.mask import MaskFactory, NullMaskFactory, NoParameterNamesMask
+
+from .finder.doxygen.core import DoxygenItemFinderFactoryCreator
+from .finder.doxygen.matcher import ItemMatcherFactory
+from .directive.base import BaseDirective, DoxygenBaseDirective, WarningHandler, create_warning
+from .directive.index import DoxygenIndexDirective, AutoDoxygenIndexDirective
+from .directive.file import DoxygenFileDirective, AutoDoxygenFileDirective
+from .process import AutoDoxygenProcessHandle
+from .exception import BreatheError
+from .project import ProjectInfoFactory, ProjectError
 
 from docutils.parsers.rst.directives import unchanged_required, unchanged, flag
 from docutils.statemachine import ViewList
+from docutils.core import publish_from_doctree
 from sphinx.domains.cpp import DefinitionParser
+from sphinx.writers.text import TextWriter
+from sphinx.builders.text import TextBuilder
 
 import docutils.nodes
 import sphinx.addnodes
 import sphinx.ext.mathbase
 
+from StringIO import StringIO
+
 import os
 import fnmatch
 import re
@@ -41,48 +48,41 @@ class NoMatchingFunctionError(BreatheError):
 
 
 class UnableToResolveFunctionError(BreatheError):
-    pass
+
+    def __init__(self, signatures):
+        self.signatures = signatures
 
 
 class NodeNotFoundError(BreatheError):
     pass
 
 
+class FakeDestination(object):
+
+    def write(self, output):
+        return output
+
+
+class TextRenderer(object):
+
+    def __init__(self, app):
+        self.app = app
+
+    def render(self, nodes, document):
+
+        new_document = document.copy()
+
+        new_document.children = nodes
+
+        writer = TextWriter(TextBuilder(self.app))
+        output = writer.write(new_document, FakeDestination())
+
+        return output.strip()
+
+
 # Directives
 # ----------
 
-class WarningHandler(object):
-
-    def __init__(self, state, context):
-        self.state = state
-        self.context = context
-
-    def warn(self, text):
-        result = text.format(**self.context)
-        return [
-            docutils.nodes.warning("", docutils.nodes.paragraph("", "", docutils.nodes.Text(result))),
-            self.state.document.reporter.warning(result, line=self.context['lineno'])
-            ]
-
-
-def create_warning(project_info, state, lineno, **kwargs):
-
-    tail = ''
-    if project_info:
-        tail = 'in doxygen xml output for project "{project}" from directory: {path}'.format(
-            project=project_info.name(),
-            path=project_info.project_path()
-            )
-
-    context = dict(
-        lineno=lineno,
-        tail=tail,
-        **kwargs
-        )
-
-    return WarningHandler(state, context)
-
-
 class DoxygenFunctionDirective(BaseDirective):
 
     required_arguments = 1
@@ -95,6 +95,12 @@ class DoxygenFunctionDirective(BaseDirective):
     has_content = False
     final_argument_whitespace = True
 
+    def __init__(self, node_factory, text_renderer, *args, **kwargs):
+        super(DoxygenFunctionDirective, self).__init__(*args, **kwargs)
+
+        self.node_factory = node_factory
+        self.text_renderer = text_renderer
+
     def run(self):
 
         # Separate possible arguments (delimited by a "(") from the namespace::name
@@ -122,15 +128,10 @@ class DoxygenFunctionDirective(BaseDirective):
         # Extract arguments from the function name.
         args = self.parse_args(args)
 
-        matcher_stack = self.matcher_factory.create_matcher_stack(
-            {
-                "compound": self.matcher_factory.create_name_matcher(namespace),
-                "member": self.matcher_factory.create_name_type_matcher(function_name, "function")
-                },
-            "member"
-            )
+        finder_filter = self.filter_factory.create_function_finder_filter(namespace, function_name)
 
-        results = finder.find(matcher_stack)
+        matches = []
+        finder.filter_(finder_filter, matches)
 
         # Create it ahead of time as it is cheap and it is ugly to declare it for both exception
         # clauses below
@@ -144,26 +145,68 @@ class DoxygenFunctionDirective(BaseDirective):
             )
 
         try:
-            data_object = self.resolve_function(results, args)
+            data_object = self.resolve_function(matches, args, project_info)
         except NoMatchingFunctionError:
             return warning.warn('doxygenfunction: Cannot find function "{namespace}{function}" '
                                 '{tail}')
-        except UnableToResolveFunctionError:
-            return warning.warn('doxygenfunction: Unable to resolve multiple matches for function '
-                                '"{namespace}{function}" with arguments ({args}) {tail}')
+        except UnableToResolveFunctionError as error:
+            message = 'doxygenfunction: Unable to resolve multiple matches for function ' \
+                '"{namespace}{function}" with arguments ({args}) {tail}.\n' \
+                'Potential matches:\n'
+
+            # We want to create a raw_text string for the console output and a set of docutils nodes
+            # for rendering into the final output. We handle the final output as a literal string
+            # with a txt based list of the options.
+            raw_text = message
+            literal_text = ''
+
+            # TODO: We're cheating here with the set() as signatures has repeating entries for some
+            # reason (failures in the matcher_stack code) so we consolidate them by shoving them in
+            # a set to remove duplicates. Should be fixed!
+            for i, entry in enumerate(set(error.signatures)):
+                if i: literal_text += '\n'
+                # Replace new lines with a new line & enough spacing to reach the appropriate
+                # alignment for our simple plain text list
+                literal_text += '- %s' % entry.replace('\n', '\n  ')
+                raw_text += '    - %s\n' % entry.replace('\n', '\n      ')
+            block = self.node_factory.literal_block('', '', self.node_factory.Text(literal_text))
+            formatted_message = warning.format(message)
+            warning_nodes = [
+                self.node_factory.paragraph(
+                    "", "",
+                    self.node_factory.Text(formatted_message)
+                    ),
+                block
+                ]
+            result = warning.warn(raw_text, warning_nodes)
+            return result
 
         target_handler = self.target_handler_factory.create_target_handler(
             self.options, project_info, self.state.document
             )
         filter_ = self.filter_factory.create_outline_filter(self.options)
 
-        return self.render(data_object, project_info, filter_, target_handler)
+        mask_factory = NullMaskFactory()
+        return self.render(data_object, project_info, filter_, target_handler, mask_factory)
 
     def parse_args(self, function_description):
+        # Strip off trailing qualifiers
+        function_description = re.sub(r'''(?<= \)) \s*
+                                          (?: const)? \s*
+                                          (?: volatile)? \s*
+                                          (?: = \s* 0)? \s* $ ''',
+                                      '',
+                                      function_description,
+                                      flags=re.VERBOSE)
 
         paren_index = function_description.find('(')
         if paren_index == -1:
             return []
+        # If it is empty parenthesis, then return empty list as we want empty parenthesis coming
+        # from the xml file to match the user's function when the user doesn't provide parenthesis
+        # ie. when there are no args anyway
+        elif function_description == '()':
+            return []
         else:
             # Parse the function name string, eg. f(int, float) to
             # extract the types so we can use them for matching
@@ -183,7 +226,7 @@ class DoxygenFunctionDirective(BaseDirective):
 
             return args
 
-    def resolve_function(self, matches, args):
+    def resolve_function(self, matches, args, project_info):
 
         if not matches:
             raise NoMatchingFunctionError()
@@ -193,33 +236,41 @@ class DoxygenFunctionDirective(BaseDirective):
 
         data_object = None
 
-        # Tries to match the args array agains the arguments listed in the
-        # doxygen data
-        # TODO: We don't have any doxygen xml dom accessing code at this level
-        # this might benefit from being abstracted away at some point
+        signatures = []
+
+        # Iterate over the potential matches
         for entry in matches:
-            if len(args) == len(entry.param):
-                equal = True
-                for i in range(len(args)):
-                    param_type = entry.param[i].type_.content_[0].value
-                    if not isinstance(param_type, unicode):
-                        param_type = param_type.valueOf_
-                    if args[i] != param_type:
-                        equal = False
-                        break
-                if equal:
-                    data_object = entry
-                    break
+
+            # Render the matches to docutils nodes
+            target_handler = self.target_handler_factory.create_target_handler(
+                {'no-link': u''}, project_info, self.state.document
+                )
+            filter_ = self.filter_factory.create_outline_filter({'outline', ''})
+            mask_factory = MaskFactory({'param': NoParameterNamesMask})
+            nodes = self.render(entry, project_info, filter_, target_handler, mask_factory)
+
+            # Render the nodes to text
+            signature = self.text_renderer.render(nodes, self.state.document)
+            signatures.append(signature)
+
+            match = re.match(r"([^(]*)(.*)", signature)
+            function, match_args = match.group(1), match.group(2)
+
+            # Parse the text to find the arguments
+            match_args = self.parse_args(match_args)
+
+            # Match them against the arg spec
+            if args == match_args:
+                data_object = entry
+                break
 
         if not data_object:
-            raise UnableToResolveFunctionError()
+            raise UnableToResolveFunctionError(signatures)
 
         return data_object
 
 
-class DoxygenClassDirective(BaseDirective):
-
-    kind = "class"
+class DoxygenClassLikeDirective(BaseDirective):
 
     required_arguments = 1
     optional_arguments = 1
@@ -227,7 +278,9 @@ class DoxygenClassDirective(BaseDirective):
         "path": unchanged_required,
         "project": unchanged_required,
         "members": unchanged,
-        "sections": unchanged,
+        "protected-members": flag,
+        "private-members": flag,
+        "undoc-members": flag,
         "show": unchanged_required,
         "outline": flag,
         "no-link": flag,
@@ -241,14 +294,14 @@ class DoxygenClassDirective(BaseDirective):
         try:
             project_info = self.project_info_factory.create_project_info(self.options)
         except ProjectError as e:
-            warning = create_warning(None, self.state, self.lineno)
-            return warning.warn('doxygenclass: %s' % e)
+            warning = create_warning(None, self.state, self.lineno, kind=self.kind)
+            return warning.warn('doxygen{kind}: %s' % e)
 
         try:
             finder = self.finder_factory.create_finder(project_info)
         except MTimerError as e:
-            warning = create_warning(None, self.state, self.lineno)
-            return warning.warn('doxygenclass: %s' % e)
+            warning = create_warning(None, self.state, self.lineno, kind=self.kind)
+            return warning.warn('doxygen{kind}: %s' % e)
 
         matcher_stack = self.matcher_factory.create_matcher_stack(
             {
@@ -260,20 +313,31 @@ class DoxygenClassDirective(BaseDirective):
         try:
             data_object = finder.find_one(matcher_stack)
         except NoMatchesError as e:
-            warning = create_warning(project_info, self.state, self.lineno, name=name)
-            return warning.warn('doxygenclass: Cannot find class "{name}" {tail}')
+            warning = create_warning(project_info, self.state, self.lineno, name=name,
+                                     kind=self.kind)
+            return warning.warn('doxygen{kind}: Cannot find class "{name}" {tail}')
 
         target_handler = self.target_handler_factory.create_target_handler(
             self.options, project_info, self.state.document
             )
-        filter_ = self.filter_factory.create_class_filter(self.options)
+        filter_ = self.filter_factory.create_class_filter(name, self.options)
 
-        return self.render(data_object, project_info, filter_, target_handler)
+        mask_factory = NullMaskFactory()
+        return self.render(data_object, project_info, filter_, target_handler, mask_factory)
 
 
-class DoxygenGroupDirective(BaseDirective):
+class DoxygenClassDirective(DoxygenClassLikeDirective):
 
-    kind = "group"
+    kind = "class"
+
+
+class DoxygenStructDirective(DoxygenClassLikeDirective):
+
+    kind = "struct"
+
+
+class DoxygenContentBlockDirective(BaseDirective):
+    """Base class for namespace and group directives which have very similar behaviours"""
 
     required_arguments = 1
     optional_arguments = 1
@@ -281,7 +345,12 @@ class DoxygenGroupDirective(BaseDirective):
         "path": unchanged_required,
         "project": unchanged_required,
         "content-only": flag,
-        "no-link": flag,
+        "outline": flag,
+        "members": flag,
+        "protected-members": flag,
+        "private-members": flag,
+        "undoc-members": flag,
+        "no-link": flag
         }
     has_content = False
 
@@ -292,35 +361,36 @@ class DoxygenGroupDirective(BaseDirective):
         try:
             project_info = self.project_info_factory.create_project_info(self.options)
         except ProjectError as e:
-            warning = create_warning(None, self.state, self.lineno)
-            return warning.warn('doxygengroup: %s' % e)
+            warning = create_warning(None, self.state, self.lineno, kind=self.kind)
+            return warning.warn('doxygen{kind}: %s' % e)
 
         try:
             finder = self.finder_factory.create_finder(project_info)
         except MTimerError as e:
-            warning = create_warning(None, self.state, self.lineno)
-            return warning.warn('doxygengroup: %s' % e)
+            warning = create_warning(None, self.state, self.lineno, kind=self.kind)
+            return warning.warn('doxygen{kind}: %s' % e)
 
-        finder_filter = self.filter_factory.create_group_finder_filter(name)
+        finder_filter = self.filter_factory.create_finder_filter(self.kind, name)
 
         matches = []
         finder.filter_(finder_filter, matches)
 
-        # It shouldn't be possible to have too many matches as groups in their nature are merged
-        # together if there are multiple declarations, so we only check for no matches
+        # It shouldn't be possible to have too many matches as namespaces & groups in their nature
+        # are merged together if there are multiple declarations, so we only check for no matches
         if not matches:
-            warning = create_warning(project_info, self.state, self.lineno, name=name)
-            return warning.warn('doxygengroup: Cannot find group "{name}" {tail}')
+            warning = create_warning(project_info, self.state, self.lineno, name=name,
+                                     kind=self.kind)
+            return warning.warn('doxygen{kind}: Cannot find namespace "{name}" {tail}')
 
         if 'content-only' in self.options:
 
             # Unpack the single entry in the matches list
             (data_object,) = matches
 
-            filter_ = self.filter_factory.create_group_content_filter()
+            filter_ = self.filter_factory.create_content_filter(self.kind, self.options)
 
-            # Having found the compound node for the group in the index we want to grab the contents
-            # of
+            # Having found the compound node for the namespace or group in the index we want to grab
+            # the contents of it which match the filter
             contents_finder = self.finder_factory.create_finder_from_root(data_object, project_info)
             contents = []
             contents_finder.filter_(filter_, contents)
@@ -331,7 +401,7 @@ class DoxygenGroupDirective(BaseDirective):
         target_handler = self.target_handler_factory.create_target_handler(
             self.options, project_info, self.state.document
             )
-        filter_ = self.filter_factory.create_open_filter()
+        filter_ = self.filter_factory.create_render_filter(self.kind, self.options)
 
         renderer_factory_creator = self.renderer_factory_creator_constructor.create_factory_creator(
             project_info,
@@ -350,37 +420,29 @@ class DoxygenGroupDirective(BaseDirective):
                 target_handler,
                 )
 
-            object_renderer = renderer_factory.create_renderer(self.root_data_object, data_object)
+            mask_factory = NullMaskFactory()
+            context = RenderContext([data_object, self.root_data_object], mask_factory)
+            object_renderer = renderer_factory.create_renderer(context)
             node_list.extend(object_renderer.render())
 
         return node_list
 
 
-class DoxygenStructDirective(DoxygenBaseDirective):
+class DoxygenNamespaceDirective(DoxygenContentBlockDirective):
 
-    kind = "struct"
+    kind = "namespace"
 
-    def create_matcher_stack(self, namespace, name):
 
-        # Structs are stored in the xml file with their fully namespaced name
-        # We're using C++ namespaces here, it might be best to make this file
-        # type dependent
-        #
-        xml_name = "%s::%s" % (namespace, name) if namespace else name
+class DoxygenGroupDirective(DoxygenContentBlockDirective):
 
-        return self.matcher_factory.create_matcher_stack(
-            {
-                "compound": self.matcher_factory.create_name_type_matcher(xml_name, self.kind)
-                },
-            "compound"
-            )
+    kind = "group"
 
 
 # This class was the same as the DoxygenBaseDirective above, except that it
 # wraps the output in a definition_list before passing it back. This should be
-# abstracted in a far nicely way to avoid repeating so much code
+# abstracted in a far nicer way to avoid repeating so much code
 #
-# Now we're removed the definition_list wrap so we really need to refactor this!
+# Now we've removed the definition_list wrap so we really need to refactor this!
 class DoxygenBaseItemDirective(BaseDirective):
 
     required_arguments = 1
@@ -428,7 +490,8 @@ class DoxygenBaseItemDirective(BaseDirective):
             )
         filter_ = self.filter_factory.create_outline_filter(self.options)
 
-        return self.render(data_object, project_info, filter_, target_handler)
+        mask_factory = NullMaskFactory()
+        return self.render(data_object, project_info, filter_, target_handler, mask_factory)
 
 
 class DoxygenVariableDirective(DoxygenBaseItemDirective):
@@ -550,14 +613,18 @@ class DoxygenDirectiveFactory(object):
         "doxygenenum": DoxygenEnumDirective,
         "doxygentypedef": DoxygenTypedefDirective,
         "doxygenunion": DoxygenUnionDirective,
+        "doxygennamespace": DoxygenNamespaceDirective,
         "doxygengroup": DoxygenGroupDirective,
         "doxygenfile": DoxygenFileDirective,
         "autodoxygenfile": AutoDoxygenFileDirective,
         }
 
-    def __init__(self, root_data_object, renderer_factory_creator_constructor, finder_factory,
-                 matcher_factory, project_info_factory, filter_factory, target_handler_factory):
+    def __init__(self, node_factory, text_renderer, root_data_object,
+                 renderer_factory_creator_constructor, finder_factory, matcher_factory,
+                 project_info_factory, filter_factory, target_handler_factory):
 
+        self.node_factory = node_factory
+        self.text_renderer = text_renderer
         self.root_data_object = root_data_object
         self.renderer_factory_creator_constructor = renderer_factory_creator_constructor
         self.finder_factory = finder_factory
@@ -572,7 +639,20 @@ class DoxygenDirectiveFactory(object):
         return self.create_directive_container("doxygenindex")
 
     def create_function_directive_container(self):
-        return self.create_directive_container("doxygenfunction")
+
+        # Pass text_renderer to the function directive
+        return DirectiveContainer(
+            self.directives["doxygenfunction"],
+            self.node_factory,
+            self.text_renderer,
+            self.root_data_object,
+            self.renderer_factory_creator_constructor,
+            self.finder_factory,
+            self.matcher_factory,
+            self.project_info_factory,
+            self.filter_factory,
+            self.target_handler_factory
+            )
 
     def create_struct_directive_container(self):
         return self.create_directive_container("doxygenstruct")
@@ -592,6 +672,9 @@ class DoxygenDirectiveFactory(object):
     def create_file_directive_container(self):
         return self.create_directive_container("doxygenfile")
 
+    def create_namespace_directive_container(self):
+        return self.create_directive_container("doxygennamespace")
+
     def create_group_directive_container(self):
         return self.create_directive_container("doxygengroup")
 
@@ -780,8 +863,9 @@ def setup(app):
     mtimer = MTimer(os.path.getmtime)
     file_state_cache = FileStateCache(mtimer, app)
     parser_factory = DoxygenParserFactory(cache, path_handler, file_state_cache)
-    matcher_factory = ItemMatcherFactory()
-    item_finder_factory_creator = DoxygenItemFinderFactoryCreator(parser_factory, matcher_factory)
+    glob_factory = GlobFactory(fnmatch.fnmatch)
+    filter_factory = FilterFactory(glob_factory, path_handler)
+    item_finder_factory_creator = DoxygenItemFinderFactoryCreator(parser_factory, filter_factory)
     index_parser = parser_factory.create_index_parser()
     finder_factory = FinderFactory(index_parser, item_finder_factory_creator)
 
@@ -812,13 +896,16 @@ def setup(app):
     # with the breathe_build_directory config variable
     build_dir = os.path.dirname(app.doctreedir.rstrip(os.sep))
     project_info_factory = ProjectInfoFactory(app.srcdir, build_dir, app.confdir, fnmatch.fnmatch)
-    glob_factory = GlobFactory(fnmatch.fnmatch)
-    filter_factory = FilterFactory(glob_factory, path_handler)
     target_handler_factory = TargetHandlerFactory(node_factory)
+    matcher_factory = ItemMatcherFactory()
 
     root_data_object = RootDataObject()
 
+    text_renderer = TextRenderer(app)
+
     directive_factory = DoxygenDirectiveFactory(
+        node_factory,
+        text_renderer,
         root_data_object,
         renderer_factory_creator_constructor,
         finder_factory,
@@ -828,6 +915,8 @@ def setup(app):
         target_handler_factory
         )
 
+    DoxygenFunctionDirective.app = app
+
     app.add_directive(
         "doxygenindex",
         directive_factory.create_index_directive_container(),
@@ -868,6 +957,11 @@ def setup(app):
         directive_factory.create_file_directive_container(),
         )
 
+    app.add_directive(
+        "doxygennamespace",
+        directive_factory.create_namespace_directive_container(),
+        )
+
     app.add_directive(
         "doxygengroup",
         directive_factory.create_group_directive_container(),
@@ -899,6 +993,8 @@ def setup(app):
     app.add_config_value("breathe_domain_by_file_pattern", {}, True)
     app.add_config_value("breathe_projects_source", {}, True)
     app.add_config_value("breathe_build_directory", '', True)
+    app.add_config_value("breathe_default_members", (), True)
+    app.add_config_value("breathe_implementation_filename_extensions", ['.c', '.cc', '.cpp'], True)
 
     app.add_stylesheet("breathe.css")
 
@@ -913,6 +1009,8 @@ def setup(app):
 
     app.connect("builder-inited", directive_factory.get_config_values)
 
+    app.connect("builder-inited", filter_factory.get_config_values)
+
     app.connect("env-get-outdated", file_state_cache.get_outdated)
 
     app.connect("env-purge-doc", file_state_cache.purge_doc)
