@@ -8,8 +8,6 @@ from xml.dom import minidom
 from xml.dom import Node
 from xml.parsers.expat import ExpatError
 
-from docutils import nodes
-
 import compoundsuper as supermod
 from compoundsuper import MixedContainer
 
@@ -25,11 +23,25 @@ supermod.DoxygenType.subclass = DoxygenTypeSub
 
 
 class compounddefTypeSub(supermod.compounddefType):
-    
+
     node_type = "compounddef"
 
-    def __init__(self, kind=None, prot=None, id=None, compoundname='', title='', basecompoundref=None, derivedcompoundref=None, includes=None, includedby=None, incdepgraph=None, invincdepgraph=None, innerdir=None, innerfile=None, innerclass=None, innernamespace=None, innerpage=None, innergroup=None, templateparamlist=None, sectiondef=None, briefdescription=None, detaileddescription=None, inheritancegraph=None, collaborationgraph=None, programlisting=None, location=None, listofallmembers=None):
-        supermod.compounddefType.__init__(self, kind, prot, id, compoundname, title, basecompoundref, derivedcompoundref, includes, includedby, incdepgraph, invincdepgraph, innerdir, innerfile, innerclass, innernamespace, innerpage, innergroup, templateparamlist, sectiondef, briefdescription, detaileddescription, inheritancegraph, collaborationgraph, programlisting, location, listofallmembers)
+    def __init__(self, kind=None, prot=None, id=None, compoundname='', title='',
+                 basecompoundref=None, derivedcompoundref=None, includes=None, includedby=None,
+                 incdepgraph=None, invincdepgraph=None, innerdir=None, innerfile=None,
+                 innerclass=None, innernamespace=None, innerpage=None, innergroup=None,
+                 templateparamlist=None, sectiondef=None, briefdescription=None,
+                 detaileddescription=None, inheritancegraph=None, collaborationgraph=None,
+                 programlisting=None, location=None, listofallmembers=None):
+
+        supermod.compounddefType.__init__(self, kind, prot, id, compoundname, title,
+                                          basecompoundref, derivedcompoundref, includes, includedby,
+                                          incdepgraph, invincdepgraph, innerdir, innerfile,
+                                          innerclass, innernamespace, innerpage, innergroup,
+                                          templateparamlist, sectiondef, briefdescription,
+                                          detaileddescription, inheritancegraph, collaborationgraph,
+                                          programlisting, location, listofallmembers)
+
 supermod.compounddefType.subclass = compounddefTypeSub
 # end class compounddefTypeSub
 
@@ -38,7 +50,6 @@ class listofallmembersTypeSub(supermod.listofallmembersType):
 
     node_type = "listofallmembers"
 
-
     def __init__(self, member=None):
         supermod.listofallmembersType.__init__(self, member)
 supermod.listofallmembersType.subclass = listofallmembersTypeSub
@@ -59,7 +70,8 @@ class compoundRefTypeSub(supermod.compoundRefType):
 
     node_type = "compoundref"
 
-    def __init__(self, virt=None, prot=None, refid=None, valueOf_='', mixedclass_=None, content_=None):
+    def __init__(self, virt=None, prot=None, refid=None, valueOf_='', mixedclass_=None,
+                 content_=None):
         supermod.compoundRefType.__init__(self, mixedclass_, content_)
 supermod.compoundRefType.subclass = compoundRefTypeSub
 # end class compoundRefTypeSub
@@ -89,7 +101,8 @@ class refTypeSub(supermod.refType):
 
     node_type = "ref"
 
-    def __init__(self, node_name, prot=None, refid=None, valueOf_='', mixedclass_=None, content_=None):
+    def __init__(self, node_name, prot=None, refid=None, valueOf_='', mixedclass_=None,
+                 content_=None):
         supermod.refType.__init__(self, mixedclass_, content_)
 
         self.node_name = node_name
@@ -101,38 +114,54 @@ class refTextTypeSub(supermod.refTextType):
 
     node_type = "reftex"
 
-    def __init__(self, refid=None, kindref=None, external=None, valueOf_='', mixedclass_=None, content_=None):
+    def __init__(self, refid=None, kindref=None, external=None, valueOf_='', mixedclass_=None,
+                 content_=None):
         supermod.refTextType.__init__(self, mixedclass_, content_)
 
 supermod.refTextType.subclass = refTextTypeSub
 # end class refTextTypeSub
 
+
 class sectiondefTypeSub(supermod.sectiondefType):
 
     node_type = "sectiondef"
 
     def __init__(self, kind=None, header='', description=None, memberdef=None):
         supermod.sectiondefType.__init__(self, kind, header, description, memberdef)
+
 supermod.sectiondefType.subclass = sectiondefTypeSub
 # end class sectiondefTypeSub
 
 
 class memberdefTypeSub(supermod.memberdefType):
 
-    node_type = "memberdef" 
+    node_type = "memberdef"
 
-    def __init__(self, initonly=None, kind=None, volatile=None, const=None, raise_=None, virt=None, readable=None, prot=None, explicit=None, new=None, final=None, writable=None, add=None, static=None, remove=None, sealed=None, mutable=None, gettable=None, inline=None, settable=None, id=None, templateparamlist=None, type_=None, definition='', argsstring='', name='', read='', write='', bitfield='', reimplements=None, reimplementedby=None, param=None, enumvalue=None, initializer=None, exceptions=None, briefdescription=None, detaileddescription=None, inbodydescription=None, location=None, references=None, referencedby=None):
-        supermod.memberdefType.__init__(self, initonly, kind, volatile, const, raise_, virt, readable, prot, explicit, new, final, writable, add, static, remove, sealed, mutable, gettable, inline, settable, id, templateparamlist, type_, definition, argsstring, name, read, write, bitfield, reimplements, reimplementedby, param, enumvalue, initializer, exceptions, briefdescription, detaileddescription, inbodydescription, location, references, referencedby)
+    def __init__(self, initonly=None, kind=None, volatile=None, const=None, raise_=None, virt=None,
+                 readable=None, prot=None, explicit=None, new=None, final=None, writable=None,
+                 add=None, static=None, remove=None, sealed=None, mutable=None, gettable=None,
+                 inline=None, settable=None, id=None, templateparamlist=None, type_=None,
+                 definition='', argsstring='', name='', read='', write='', bitfield='',
+                 reimplements=None, reimplementedby=None, param=None, enumvalue=None,
+                 initializer=None, exceptions=None, briefdescription=None, detaileddescription=None,
+                 inbodydescription=None, location=None, references=None, referencedby=None):
+
+        supermod.memberdefType.__init__(self, initonly, kind, volatile, const, raise_, virt,
+                                        readable, prot, explicit, new, final, writable, add, static,
+                                        remove, sealed, mutable, gettable, inline, settable, id,
+                                        templateparamlist, type_, definition, argsstring, name,
+                                        read, write, bitfield, reimplements, reimplementedby, param,
+                                        enumvalue, initializer, exceptions, briefdescription,
+                                        detaileddescription, inbodydescription, location,
+                                        references, referencedby)
 
         self.parameterlist = supermod.docParamListType.factory()
         self.parameterlist.kind = "param"
 
-
     def buildChildren(self, child_, nodeName_):
         supermod.memberdefType.buildChildren(self, child_, nodeName_)
-        
-        if child_.nodeType == Node.ELEMENT_NODE and \
-            nodeName_ == 'param':
+
+        if child_.nodeType == Node.ELEMENT_NODE and nodeName_ == 'param':
 
             # Get latest param
             param = self.param[-1]
@@ -147,8 +176,8 @@ class memberdefTypeSub(supermod.memberdefType):
             paramname = supermod.docParamName.factory()
 
             # Add parameter name
-            obj_ = paramname.mixedclass_(MixedContainer.CategoryText,
-                MixedContainer.TypeNone, '', param.declname)
+            obj_ = paramname.mixedclass_(MixedContainer.CategoryText, MixedContainer.TypeNone, '',
+                                         param.declname)
             paramname.content_.append(obj_)
 
             paramnamelist = supermod.docParamNameList.factory()
@@ -162,14 +191,12 @@ class memberdefTypeSub(supermod.memberdefType):
 
             self.parameterlist.parameteritem.append(paramlistitem)
 
-        elif child_.nodeType == Node.ELEMENT_NODE and \
-            nodeName_ == 'detaileddescription':
+        elif child_.nodeType == Node.ELEMENT_NODE and nodeName_ == 'detaileddescription':
 
             if not self.parameterlist.parameteritem:
                 # No items in our list
                 return
 
-
             # Assume supermod.memberdefType.buildChildren has already built the
             # description object, we just want to slot our parameterlist in at
             # a reasonable point
@@ -183,22 +210,25 @@ class memberdefTypeSub(supermod.memberdefType):
             para = supermod.docParaType.factory()
             para.parameterlist.append(self.parameterlist)
 
-            obj_ = detaileddescription.mixedclass_(MixedContainer.CategoryComplex, MixedContainer.TypeNone, 'para', para)
+            obj_ = detaileddescription.mixedclass_(MixedContainer.CategoryComplex,
+                                                   MixedContainer.TypeNone, 'para', para)
 
             index = 0
-            detaileddescription.content_.insert( index, obj_ )
-
+            detaileddescription.content_.insert(index, obj_)
 
 
 supermod.memberdefType.subclass = memberdefTypeSub
 # end class memberdefTypeSub
 
+
 class descriptionTypeSub(supermod.descriptionType):
-    
+
     node_type = "description"
 
-    def __init__(self, title='', para=None, sect1=None, internal=None, mixedclass_=None, content_=None):
+    def __init__(self, title='', para=None, sect1=None, internal=None, mixedclass_=None,
+                 content_=None):
         supermod.descriptionType.__init__(self, mixedclass_, content_)
+
 supermod.descriptionType.subclass = descriptionTypeSub
 # end class descriptionTypeSub
 
@@ -207,36 +237,33 @@ class enumvalueTypeSub(supermod.enumvalueType):
 
     node_type = "enumvalue"
 
-    def __init__(self, prot=None, id=None, name='', initializer=None, briefdescription=None, detaileddescription=None, mixedclass_=None, content_=None):
+    def __init__(self, prot=None, id=None, name='', initializer=None, briefdescription=None,
+                 detaileddescription=None, mixedclass_=None, content_=None):
         supermod.enumvalueType.__init__(self, mixedclass_, content_)
-        
+
         self.initializer = None
 
     def buildChildren(self, child_, nodeName_):
         # Get text from <name> child and put it in self.name
-        if child_.nodeType == Node.ELEMENT_NODE and \
-            nodeName_ == 'name':
+        if child_.nodeType == Node.ELEMENT_NODE and nodeName_ == 'name':
             value_ = []
             for text_ in child_.childNodes:
                 value_.append(text_.nodeValue)
             valuestr_ = ''.join(value_)
             self.name = valuestr_
-        elif child_.nodeType == Node.ELEMENT_NODE and \
-            nodeName_ == 'briefdescription':
+        elif child_.nodeType == Node.ELEMENT_NODE and nodeName_ == 'briefdescription':
             obj_ = supermod.descriptionType.factory()
             obj_.build(child_)
             self.set_briefdescription(obj_)
-        elif child_.nodeType == Node.ELEMENT_NODE and \
-            nodeName_ == 'detaileddescription':
+        elif child_.nodeType == Node.ELEMENT_NODE and nodeName_ == 'detaileddescription':
             obj_ = supermod.descriptionType.factory()
             obj_.build(child_)
             self.set_detaileddescription(obj_)
-        elif child_.nodeType == Node.ELEMENT_NODE and \
-            nodeName_ == 'initializer':
+        elif child_.nodeType == Node.ELEMENT_NODE and nodeName_ == 'initializer':
             childobj_ = supermod.linkedTextType.factory()
             childobj_.build(child_)
-            obj_ = self.mixedclass_(MixedContainer.CategoryComplex,
-                MixedContainer.TypeNone, 'initializer', childobj_)
+            obj_ = self.mixedclass_(MixedContainer.CategoryComplex, MixedContainer.TypeNone,
+                                    'initializer', childobj_)
             self.set_initializer(obj_)
             self.content_.append(obj_)
 
@@ -258,7 +285,8 @@ class paramTypeSub(supermod.paramType):
 
     node_type = "param"
 
-    def __init__(self, type_=None, declname='', defname='', array='', defval=None, briefdescription=None):
+    def __init__(self, type_=None, declname='', defname='', array='', defval=None,
+                 briefdescription=None):
         supermod.paramType.__init__(self, type_, declname, defname, array, defval, briefdescription)
 supermod.paramType.subclass = paramTypeSub
 # end class paramTypeSub
@@ -348,7 +376,8 @@ class referenceTypeSub(supermod.referenceType):
 
     node_type = "reference"
 
-    def __init__(self, endline=None, startline=None, refid=None, compoundref=None, valueOf_='', mixedclass_=None, content_=None):
+    def __init__(self, endline=None, startline=None, refid=None, compoundref=None, valueOf_='',
+                 mixedclass_=None, content_=None):
         supermod.referenceType.__init__(self, mixedclass_, content_)
 supermod.referenceType.subclass = referenceTypeSub
 # end class referenceTypeSub
@@ -358,7 +387,8 @@ class locationTypeSub(supermod.locationType):
 
     node_type = "location"
 
-    def __init__(self, bodystart=None, line=None, bodyend=None, bodyfile=None, file=None, valueOf_=''):
+    def __init__(self, bodystart=None, line=None, bodyend=None, bodyfile=None, file=None,
+                 valueOf_=''):
         supermod.locationType.__init__(self, bodystart, line, bodyend, bodyfile, file)
 supermod.locationType.subclass = locationTypeSub
 # end class locationTypeSub
@@ -368,7 +398,8 @@ class docSect1TypeSub(supermod.docSect1Type):
 
     node_type = "docsect1"
 
-    def __init__(self, id=None, title='', para=None, sect2=None, internal=None, mixedclass_=None, content_=None):
+    def __init__(self, id=None, title='', para=None, sect2=None, internal=None, mixedclass_=None,
+                 content_=None):
         supermod.docSect1Type.__init__(self, mixedclass_, content_)
 supermod.docSect1Type.subclass = docSect1TypeSub
 # end class docSect1TypeSub
@@ -378,7 +409,8 @@ class docSect2TypeSub(supermod.docSect2Type):
 
     node_type = "docsect2"
 
-    def __init__(self, id=None, title='', para=None, sect3=None, internal=None, mixedclass_=None, content_=None):
+    def __init__(self, id=None, title='', para=None, sect3=None, internal=None, mixedclass_=None,
+                 content_=None):
         supermod.docSect2Type.__init__(self, mixedclass_, content_)
 supermod.docSect2Type.subclass = docSect2TypeSub
 # end class docSect2TypeSub
@@ -388,7 +420,8 @@ class docSect3TypeSub(supermod.docSect3Type):
 
     node_type = "docsect3"
 
-    def __init__(self, id=None, title='', para=None, sect4=None, internal=None, mixedclass_=None, content_=None):
+    def __init__(self, id=None, title='', para=None, sect4=None, internal=None, mixedclass_=None,
+                 content_=None):
         supermod.docSect3Type.__init__(self, mixedclass_, content_)
 supermod.docSect3Type.subclass = docSect3TypeSub
 # end class docSect3TypeSub
@@ -398,7 +431,8 @@ class docSect4TypeSub(supermod.docSect4Type):
 
     node_type = "docsect4"
 
-    def __init__(self, id=None, title='', para=None, internal=None, mixedclass_=None, content_=None):
+    def __init__(self, id=None, title='', para=None, internal=None, mixedclass_=None,
+                 content_=None):
         supermod.docSect4Type.__init__(self, mixedclass_, content_)
 supermod.docSect4Type.subclass = docSect4TypeSub
 # end class docSect4TypeSub
@@ -498,7 +532,10 @@ class docListTypeSub(supermod.docListType):
 
     node_type = "doclist"
 
-    def __init__(self, listitem=None):
+    def __init__(self, listitem=None, subtype=""):
+        self.node_subtype = "itemized"
+        if subtype is not "":
+            self.node_subtype = subtype
         supermod.docListType.__init__(self, listitem)
 supermod.docListType.subclass = docListTypeSub
 # end class docListTypeSub
@@ -538,7 +575,8 @@ class docRefTextTypeSub(supermod.docRefTextType):
 
     node_type = "docreftext"
 
-    def __init__(self, refid=None, kindref=None, external=None, valueOf_='', mixedclass_=None, content_=None):
+    def __init__(self, refid=None, kindref=None, external=None, valueOf_='', mixedclass_=None,
+                 content_=None):
         supermod.docRefTextType.__init__(self, mixedclass_, content_)
 
         self.para = []
@@ -546,8 +584,7 @@ class docRefTextTypeSub(supermod.docRefTextType):
     def buildChildren(self, child_, nodeName_):
         supermod.docRefTextType.buildChildren(self, child_, nodeName_)
 
-        if child_.nodeType == Node.ELEMENT_NODE and \
-            nodeName_ == 'para':
+        if child_.nodeType == Node.ELEMENT_NODE and nodeName_ == 'para':
             obj_ = supermod.docParaType.factory()
             obj_.build(child_)
             self.para.append(obj_)
@@ -600,7 +637,8 @@ class docImageTypeSub(supermod.docImageType):
 
     node_type = "docimage"
 
-    def __init__(self, width=None, type_=None, name=None, height=None, valueOf_='', mixedclass_=None, content_=None):
+    def __init__(self, width=None, type_=None, name=None, height=None, valueOf_='',
+                 mixedclass_=None, content_=None):
         supermod.docImageType.__init__(self, mixedclass_, content_)
 supermod.docImageType.subclass = docImageTypeSub
 # end class docImageTypeSub
@@ -734,11 +772,15 @@ class verbatimTypeSub(object):
         else:
             self.content_ = content_
         self.text = ""
+
     def factory(*args, **kwargs):
         return verbatimTypeSub(*args, **kwargs)
+
     factory = staticmethod(factory)
+
     def buildAttributes(self, attrs):
         pass
+
     def build(self, node_):
         attrs = node_.attributes
         self.buildAttributes(attrs)
@@ -746,10 +788,12 @@ class verbatimTypeSub(object):
         for child_ in node_.childNodes:
             nodeName_ = child_.nodeName.split(':')[-1]
             self.buildChildren(child_, nodeName_)
+
     def buildChildren(self, child_, nodeName_):
         if child_.nodeType == Node.TEXT_NODE:
             self.text += child_.nodeValue
 
+
 class docParaTypeSub(supermod.docParaType):
 
     node_type = "docpara"
@@ -760,38 +804,33 @@ class docParaTypeSub(supermod.docParaType):
         self.parameterlist = []
         self.simplesects = []
         self.content = []
-        self.programlisting =[]
-        self.images =[]
+        self.programlisting = []
+        self.images = []
 
     def buildChildren(self, child_, nodeName_):
         supermod.docParaType.buildChildren(self, child_, nodeName_)
 
         if child_.nodeType == Node.TEXT_NODE:
             obj_ = self.mixedclass_(MixedContainer.CategoryText,
-                MixedContainer.TypeNone, '', child_.nodeValue)
+                                    MixedContainer.TypeNone, '', child_.nodeValue)
             self.content.append(obj_)
-        elif child_.nodeType == Node.ELEMENT_NODE and \
-                nodeName_ == "ref":
+        elif child_.nodeType == Node.ELEMENT_NODE and nodeName_ == "ref":
             obj_ = supermod.docRefTextType.factory()
             obj_.build(child_)
             self.content.append(obj_)
-        elif child_.nodeType == Node.ELEMENT_NODE and \
-                nodeName_ == 'parameterlist':
+        elif child_.nodeType == Node.ELEMENT_NODE and nodeName_ == 'parameterlist':
             obj_ = supermod.docParamListType.factory()
             obj_.build(child_)
             self.parameterlist.append(obj_)
-        elif child_.nodeType == Node.ELEMENT_NODE and \
-                nodeName_ == 'simplesect':
+        elif child_.nodeType == Node.ELEMENT_NODE and nodeName_ == 'simplesect':
             obj_ = supermod.docSimpleSectType.factory()
             obj_.build(child_)
             self.simplesects.append(obj_)
-        elif child_.nodeType == Node.ELEMENT_NODE and \
-                nodeName_ == 'programlisting':
+        elif child_.nodeType == Node.ELEMENT_NODE and nodeName_ == 'programlisting':
             obj_ = supermod.listingType.factory()
             obj_.build(child_)
             self.programlisting.append(obj_)
-        elif child_.nodeType == Node.ELEMENT_NODE and \
-                nodeName_ == 'image':
+        elif child_.nodeType == Node.ELEMENT_NODE and nodeName_ == 'image':
             obj_ = supermod.docImageType.factory()
             obj_.build(child_)
             self.images.append(obj_)
@@ -807,19 +846,25 @@ class docParaTypeSub(supermod.docParaType):
             obj_.build(child_)
             obj_.type_ = nodeName_
             self.content.append(obj_)
-        elif child_.nodeType == Node.ELEMENT_NODE and \
-            nodeName_ == 'verbatim':
+        elif child_.nodeType == Node.ELEMENT_NODE and nodeName_ == 'verbatim':
             childobj_ = verbatimTypeSub.factory()
             childobj_.build(child_)
-            obj_ = self.mixedclass_(MixedContainer.CategoryComplex,
-                MixedContainer.TypeNone, 'verbatim', childobj_)
+            obj_ = self.mixedclass_(MixedContainer.CategoryComplex, MixedContainer.TypeNone,
+                                    'verbatim', childobj_)
             self.content.append(obj_)
-        elif child_.nodeType == Node.ELEMENT_NODE and \
-            nodeName_ == 'formula':
+        elif child_.nodeType == Node.ELEMENT_NODE and nodeName_ == 'formula':
             childobj_ = docFormulaTypeSub.factory()
             childobj_.build(child_)
-            obj_ = self.mixedclass_(MixedContainer.CategoryComplex,
-                MixedContainer.TypeNone, 'formula', childobj_)
+            obj_ = self.mixedclass_(MixedContainer.CategoryComplex, MixedContainer.TypeNone,
+                                    'formula', childobj_)
+            self.content.append(obj_)
+        elif child_.nodeType == Node.ELEMENT_NODE and nodeName_ == "itemizedlist":
+            obj_ = supermod.docListType.factory(subtype="itemized")
+            obj_.build(child_)
+            self.content.append(obj_)
+        elif child_.nodeType == Node.ELEMENT_NODE and nodeName_ == "orderedlist":
+            obj_ = supermod.docListType.factory(subtype="ordered")
+            obj_.build(child_)
             self.content.append(obj_)
 
 supermod.docParaType.subclass = docParaTypeSub
@@ -836,20 +881,20 @@ class docMarkupTypeSub(supermod.docMarkupType):
 
     def buildChildren(self, child_, nodeName_):
         if child_.nodeType == Node.TEXT_NODE:
-            obj_ = self.mixedclass_(MixedContainer.CategoryText,
-                MixedContainer.TypeNone, '', child_.nodeValue)
+            obj_ = self.mixedclass_(MixedContainer.CategoryText, MixedContainer.TypeNone, '',
+                                    child_.nodeValue)
             self.content_.append(obj_)
-        elif child_.nodeType == Node.ELEMENT_NODE and \
-            nodeName_ == 'ref':
+        elif child_.nodeType == Node.ELEMENT_NODE and nodeName_ == 'ref':
             childobj_ = supermod.docRefTextType.factory()
             childobj_.build(child_)
-            obj_ = self.mixedclass_(MixedContainer.CategoryComplex,
-                MixedContainer.TypeNone, 'ref', childobj_)
+            obj_ = self.mixedclass_(MixedContainer.CategoryComplex, MixedContainer.TypeNone, 'ref',
+                                    childobj_)
             self.content_.append(obj_)
         if child_.nodeType == Node.TEXT_NODE:
             self.valueOf_ += child_.nodeValue
         elif child_.nodeType == Node.CDATA_SECTION_NODE:
-            self.valueOf_ += '![CDATA['+child_.nodeValue+']]'
+            self.valueOf_ += '![CDATA[' + child_.nodeValue + ']]'
+
 supermod.docMarkupType.subclass = docMarkupTypeSub
 # end class docMarkupTypeSub
 
@@ -857,10 +902,11 @@ supermod.docMarkupType.subclass = docMarkupTypeSub
 class docTitleTypeSub(supermod.docTitleType):
 
     node_type = "doctitle"
-    
+
     def __init__(self, valueOf_='', mixedclass_=None, content_=None):
         supermod.docTitleType.__init__(self, valueOf_, mixedclass_, content_)
         self.type_ = None
+
 supermod.docTitleType.subclass = docTitleTypeSub
 # end class docTitleTypeSub
 
@@ -868,16 +914,18 @@ supermod.docTitleType.subclass = docTitleTypeSub
 class ParseError(Exception):
     pass
 
+
 class FileIOError(Exception):
     pass
 
+
 def parse(inFilename):
 
     try:
         doc = minidom.parse(inFilename)
-    except IOError, e:
+    except IOError as e:
         raise FileIOError(e)
-    except ExpatError, e:
+    except ExpatError as e:
         raise ParseError(e)
 
     rootNode = doc.documentElement
