@@ -5,6 +5,7 @@ Generated Mon Feb  9 19:08:05 2009 by generateDS.py.
 """
 
 from xml.dom import minidom
+from xml.parsers.expat import ExpatError
 
 
 import indexsuper as supermod
@@ -49,9 +50,9 @@ def parse(inFilename):
 
     try:
         doc = minidom.parse(inFilename)
-    except IOError, e:
+    except IOError as e:
         raise FileIOError(e)
-    except ExpatError, e:
+    except ExpatError as e:
         raise ParseError(e)
 
     rootNode = doc.documentElement
