@@ -6,7 +6,8 @@ class DoxygenTypeSubRenderer(Renderer):
 
     def render(self):
 
-        compound_renderer = self.renderer_factory.create_renderer(self.data_object, self.data_object.compounddef)
+        context = self.context.create_child_context(self.data_object.compounddef)
+        compound_renderer = self.renderer_factory.create_renderer(context)
         return compound_renderer.render()
 
 
@@ -59,11 +60,13 @@ class CompoundDefTypeSubRenderer(Renderer):
         nodelist = []    
 
         if self.data_object.briefdescription:
-            renderer = self.renderer_factory.create_renderer(self.data_object, self.data_object.briefdescription)
+            context = self.context.create_child_context(self.data_object.briefdescription)
+            renderer = self.renderer_factory.create_renderer(context)
             nodelist.extend(renderer.render())
 
         if self.data_object.detaileddescription:
-            renderer = self.renderer_factory.create_renderer(self.data_object, self.data_object.detaileddescription)
+            context = self.context.create_child_context(self.data_object.detaileddescription)
+            renderer = self.renderer_factory.create_renderer(context)
             nodelist.extend(renderer.render())
 
         section_nodelists = {}
@@ -74,7 +77,8 @@ class CompoundDefTypeSubRenderer(Renderer):
             node = self.node_factory.desc()
             node.document = self.state.document
             node['objtype'] = kind
-            renderer = self.renderer_factory.create_renderer(self.data_object, sectiondef)
+            context = self.context.create_child_context(sectiondef)
+            renderer = self.renderer_factory.create_renderer(context)
             node.extend(renderer.render())
             try:
                 # As "user-defined" can repeat
@@ -88,11 +92,13 @@ class CompoundDefTypeSubRenderer(Renderer):
 
         # Take care of innerclasses
         for innerclass in self.data_object.innerclass:
-            renderer = self.renderer_factory.create_renderer(self.data_object, innerclass)
+            context = self.context.create_child_context(innerclass)
+            renderer = self.renderer_factory.create_renderer(context)
             nodelist.extend(renderer.render())
 
         for innernamespace in self.data_object.innernamespace:
-            renderer = self.renderer_factory.create_renderer(self.data_object, innernamespace)
+            context = self.context.create_child_context(innernamespace)
+            renderer = self.renderer_factory.create_renderer(context)
             nodelist.extend(renderer.render())
 
         return nodelist
@@ -107,12 +113,14 @@ class SectionDefTypeSubRenderer(Renderer):
         node_list = []
 
         if self.data_object.description:
-            renderer = self.renderer_factory.create_renderer(self.data_object, self.data_object.description)
+            context = self.context.create_child_context(self.data_object.description)
+            renderer = self.renderer_factory.create_renderer(context)
             node_list.extend(renderer.render())
 
         # Get all the memberdef info
         for memberdef in self.data_object.memberdef:
-            renderer = self.renderer_factory.create_renderer(self.data_object, memberdef)
+            context = self.context.create_child_context(memberdef)
+            renderer = self.renderer_factory.create_renderer(context)
             node_list.extend(renderer.render())
 
         if node_list:
@@ -168,10 +176,13 @@ class MemberDefTypeSubRenderer(Renderer):
 
         # Variable type or function return type
         if self.data_object.type_:
-            renderer = self.renderer_factory.create_renderer(self.data_object, self.data_object.type_)
+            context = self.context.create_child_context(self.data_object.type_)
+            renderer = self.renderer_factory.create_renderer(context)
             nodes.extend(renderer.render())
 
-        if nodes: nodes.append(self.node_factory.Text(" "))
+        if nodes:
+            nodes.append(self.node_factory.Text(" "))
+
         nodes.append(self.node_factory.desc_name(text=self.data_object.name))
 
         return nodes
@@ -181,11 +192,13 @@ class MemberDefTypeSubRenderer(Renderer):
         nodes = []
 
         if self.data_object.briefdescription:
-            renderer = self.renderer_factory.create_renderer(self.data_object, self.data_object.briefdescription)
+            context = self.context.create_child_context(self.data_object.briefdescription)
+            renderer = self.renderer_factory.create_renderer(context)
             nodes.extend(renderer.render())
 
         if self.data_object.detaileddescription:
-            renderer = self.renderer_factory.create_renderer(self.data_object, self.data_object.detaileddescription)
+            context = self.context.create_child_context(self.data_object.detaileddescription)
+            renderer = self.renderer_factory.create_renderer(context)
             nodes.extend(renderer.render())
 
         return nodes
@@ -226,15 +239,17 @@ class FuncMemberDefTypeSubRenderer(MemberDefTypeSubRenderer):
 
         # Handle any template information
         if self.data_object.templateparamlist:
-            renderer = self.renderer_factory.create_renderer(
-                    self.data_object,
-                    self.data_object.templateparamlist
-                    )
+            context = self.context.create_child_context(self.data_object.templateparamlist)
+            renderer = self.renderer_factory.create_renderer(context)
             template_nodes = [self.node_factory.Text("template <")]
             template_nodes.extend(renderer.render())
             template_nodes.append(self.node_factory.Text("> "))
             nodes.append(self.node_factory.line("", *template_nodes))
 
+        # Note whether a member function is virtual
+        if self.data_object.virt != 'non-virtual':
+            nodes.append(self.node_factory.Text('virtual '))
+
         # Get the function type and name
         nodes.extend(MemberDefTypeSubRenderer.title(self))
 
@@ -242,11 +257,26 @@ class FuncMemberDefTypeSubRenderer(MemberDefTypeSubRenderer):
         paramlist = self.node_factory.desc_parameterlist()
         for i, parameter in enumerate(self.data_object.param):
             param = self.node_factory.desc_parameter('', '', noemph=True)
-            renderer = self.renderer_factory.create_renderer(self.data_object, parameter)
+            context = self.context.create_child_context(parameter)
+            renderer = self.renderer_factory.create_renderer(context)
             param.extend(renderer.render())
             paramlist.append(param)
         nodes.append(paramlist)
 
+        # Add CV-qualifiers
+        if self.data_object.const == 'yes':
+            nodes.append(self.node_factory.Text(' const'))
+        # The doxygen xml output doesn't seem to properly register 'volatile' as the xml attribute
+        # 'volatile' so we have to check the argsstring for the moment. Maybe it'll change in
+        # doxygen at some point. Registered as bug:
+        #     https://bugzilla.gnome.org/show_bug.cgi?id=733451
+        if self.data_object.volatile == 'yes' or self.data_object.argsstring.endswith('volatile'):
+            nodes.append(self.node_factory.Text(' volatile'))
+
+        # Add `= 0` for pure virtual members.
+        if self.data_object.virt == 'pure-virtual':
+            nodes.append(self.node_factory.Text(' = 0'))
+
         return nodes
 
 
@@ -260,7 +290,8 @@ class DefineMemberDefTypeSubRenderer(MemberDefTypeSubRenderer):
             title.append(self.node_factory.Text("("))
             for i, parameter in enumerate(self.data_object.param):
                 if i: title.append(self.node_factory.Text(", "))
-                renderer = self.renderer_factory.create_renderer(self.data_object, parameter)
+                context = self.context.create_child_context(parameter)
+                renderer = self.renderer_factory.create_renderer(context)
                 title.extend(renderer.render())
             title.append(self.node_factory.Text(")"))
 
@@ -292,7 +323,8 @@ class EnumMemberDefTypeSubRenderer(MemberDefTypeSubRenderer):
 
         enums = []
         for item in self.data_object.enumvalue:
-            renderer = self.renderer_factory.create_renderer(self.data_object, item)
+            context = self.context.create_child_context(item)
+            renderer = self.renderer_factory.create_renderer(context)
             enums.extend(renderer.render())
 
         description_nodes.append(self.node_factory.bullet_list("", classes=["breatheenumvalues"], *enums))
@@ -308,7 +340,8 @@ class TypedefMemberDefTypeSubRenderer(MemberDefTypeSubRenderer):
         args.extend(MemberDefTypeSubRenderer.title(self))
 
         if self.data_object.argsstring:
-            renderer = self.renderer_factory.create_renderer(self.data_object, self.data_object.argsstring)
+            context = self.context.create_child_context(self.data_object.argsstring)
+            renderer = self.renderer_factory.create_renderer(context)
             args.extend(renderer.render())
 
         return args
@@ -321,7 +354,8 @@ class VariableMemberDefTypeSubRenderer(MemberDefTypeSubRenderer):
         args = MemberDefTypeSubRenderer.title(self)
 
         if self.data_object.argsstring:
-            renderer = self.renderer_factory.create_renderer(self.data_object, self.data_object.argsstring)
+            context = self.context.create_child_context(self.data_object.argsstring)
+            renderer = self.renderer_factory.create_renderer(context)
             args.extend(renderer.render())
 
         return args
@@ -335,7 +369,8 @@ class EnumvalueTypeSubRenderer(Renderer):
         description_nodes = [name]
 
         if self.data_object.initializer:
-            renderer = self.renderer_factory.create_renderer(self.data_object, self.data_object.initializer)
+            context = self.context.create_child_context(self.data_object.initializer)
+            renderer = self.renderer_factory.create_renderer(context)
             nodelist = [self.node_factory.Text(" = ")]
             nodelist.extend(renderer.render())
             description_nodes.append(self.node_factory.literal("", "", *nodelist))
@@ -344,25 +379,29 @@ class EnumvalueTypeSubRenderer(Renderer):
         description_nodes.append(separator)
 
         if self.data_object.briefdescription:
-            renderer = self.renderer_factory.create_renderer(self.data_object, self.data_object.briefdescription)
+            context = self.context.create_child_context(self.data_object.briefdescription)
+            renderer = self.renderer_factory.create_renderer(context)
             description_nodes.extend(renderer.render())
 
         if self.data_object.detaileddescription:
-            renderer = self.renderer_factory.create_renderer(self.data_object, self.data_object.detaileddescription)
+            context = self.context.create_child_context(self.data_object.detaileddescription)
+            renderer = self.renderer_factory.create_renderer(context)
             description_nodes.extend(renderer.render())
 
         # Build the list item
         return [self.node_factory.list_item("", *description_nodes)]
 
+
 class DescriptionTypeSubRenderer(Renderer):
 
     def render(self):
 
         nodelist = []
-        
+
         # Get description in rst_nodes if possible
         for item in self.data_object.content_:
-            renderer = self.renderer_factory.create_renderer(self.data_object, item)
+            context = self.context.create_child_context(item)
+            renderer = self.renderer_factory.create_renderer(context)
             nodelist.extend(renderer.render())
 
         return nodelist
@@ -376,9 +415,8 @@ class LinkedTextTypeSubRenderer(Renderer):
 
         # Recursively process where possible
         for i, entry in enumerate(self.data_object.content_):
-            if i:
-                nodelist.append(self.node_factory.Text(" "))
-            renderer = self.renderer_factory.create_renderer(self.data_object, entry)
+            context = self.context.create_child_context(entry)
+            renderer = self.renderer_factory.create_renderer(context)
             nodelist.extend(renderer.render())
 
         return nodelist
@@ -402,7 +440,8 @@ class ParamTypeSubRenderer(Renderer):
 
         # Parameter type
         if self.data_object.type_:
-            renderer = self.renderer_factory.create_renderer(self.data_object, self.data_object.type_)
+            context = self.context.create_child_context(self.data_object.type_)
+            renderer = self.renderer_factory.create_renderer(context)
             nodelist.extend(renderer.render())
 
         # Parameter name
@@ -417,7 +456,8 @@ class ParamTypeSubRenderer(Renderer):
         # Default value
         if self.data_object.defval:
             nodelist.append(self.node_factory.Text(" = "))
-            renderer = self.renderer_factory.create_renderer(self.data_object, self.data_object.defval)
+            context = self.context.create_child_context(self.data_object.defval)
+            renderer = self.renderer_factory.create_renderer(context)
             nodelist.extend(renderer.render())
 
         return nodelist
@@ -431,11 +471,13 @@ class DocRefTextTypeSubRenderer(Renderer):
         nodelist = []
 
         for item in self.data_object.content_:
-            renderer = self.renderer_factory.create_renderer(self.data_object, item)
+            context = self.context.create_child_context(item)
+            renderer = self.renderer_factory.create_renderer(context)
             nodelist.extend(renderer.render())
 
         for item in self.data_object.para:
-            renderer = self.renderer_factory.create_renderer(self.data_object, item)
+            context = self.context.create_child_context(item)
+            renderer = self.renderer_factory.create_renderer(context)
             nodelist.extend(renderer.render())
 
         refid = "%s%s" % (self.project_info.name(), self.data_object.refid)
@@ -466,24 +508,29 @@ class DocParaTypeSubRenderer(Renderer):
 
         nodelist = []
         for item in self.data_object.content:              # Description
-            renderer = self.renderer_factory.create_renderer(self.data_object, item)
+            context = self.context.create_child_context(item)
+            renderer = self.renderer_factory.create_renderer(context)
             nodelist.extend(renderer.render())
 
         for item in self.data_object.programlisting:       # Program listings
-            renderer = self.renderer_factory.create_renderer(self.data_object, item)
+            context = self.context.create_child_context(item)
+            renderer = self.renderer_factory.create_renderer(context)
             nodelist.extend(renderer.render())
 
         for item in self.data_object.images:               # Images
-            renderer = self.renderer_factory.create_renderer(self.data_object, item)
+            context = self.context.create_child_context(item)
+            renderer = self.renderer_factory.create_renderer(context)
             nodelist.extend(renderer.render())
 
         definition_nodes = []
         for item in self.data_object.simplesects:          # Returns, user par's, etc
-            renderer = self.renderer_factory.create_renderer(self.data_object, item)
+            context = self.context.create_child_context(item)
+            renderer = self.renderer_factory.create_renderer(context)
             definition_nodes.extend(renderer.render())
 
-        for entry in self.data_object.parameterlist:       # Parameters/Exceptions
-            renderer = self.renderer_factory.create_renderer(self.data_object, entry)
+        for item in self.data_object.parameterlist:       # Parameters/Exceptions
+            context = self.context.create_child_context(item)
+            renderer = self.renderer_factory.create_renderer(context)
             definition_nodes.extend(renderer.render())
 
         if definition_nodes:
@@ -523,7 +570,8 @@ class DocMarkupTypeSubRenderer(Renderer):
         nodelist = []
 
         for item in self.data_object.content_:
-            renderer = self.renderer_factory.create_renderer(self.data_object, item)
+            context = self.context.create_child_context(item)
+            renderer = self.renderer_factory.create_renderer(context)
             nodelist.extend(renderer.render())
 
         return [self.creator("", "", *nodelist)]
@@ -542,8 +590,9 @@ class DocParamListTypeSubRenderer(Renderer):
     def render(self):
 
         nodelist = []
-        for entry in self.data_object.parameteritem:
-            renderer = self.renderer_factory.create_renderer(self.data_object, entry)
+        for item in self.data_object.parameteritem:
+            context = self.context.create_child_context(item)
+            renderer = self.renderer_factory.create_renderer(context)
             nodelist.extend(renderer.render())
 
         # Fild list entry
@@ -563,8 +612,9 @@ class DocParamListItemSubRenderer(Renderer):
     def render(self):
 
         nodelist = []
-        for entry in self.data_object.parameternamelist:
-            renderer = self.renderer_factory.create_renderer(self.data_object, entry)
+        for item in self.data_object.parameternamelist:
+            context = self.context.create_child_context(item)
+            renderer = self.renderer_factory.create_renderer(context)
             nodelist.extend(renderer.render())
 
         term = self.node_factory.literal("","", *nodelist)
@@ -574,7 +624,8 @@ class DocParamListItemSubRenderer(Renderer):
         nodelist = []
 
         if self.data_object.parameterdescription:
-            renderer = self.renderer_factory.create_renderer(self.data_object, self.data_object.parameterdescription)
+            context = self.context.create_child_context(self.data_object.parameterdescription)
+            renderer = self.renderer_factory.create_renderer(context)
             nodelist.extend(renderer.render())
 
         return [self.node_factory.list_item("", term, separator, *nodelist)]
@@ -585,8 +636,9 @@ class DocParamNameListSubRenderer(Renderer):
     def render(self):
 
         nodelist = []
-        for entry in self.data_object.parametername:
-            renderer = self.renderer_factory.create_renderer(self.data_object, entry)
+        for item in self.data_object.parametername:
+            context = self.context.create_child_context(item)
+            renderer = self.renderer_factory.create_renderer(context)
             nodelist.extend(renderer.render())
 
         return nodelist
@@ -597,7 +649,8 @@ class DocParamNameSubRenderer(Renderer):
 
         nodelist = []
         for item in self.data_object.content_:
-            renderer = self.renderer_factory.create_renderer(self.data_object, item)
+            context = self.context.create_child_context(item)
+            renderer = self.renderer_factory.create_renderer(context)
             nodelist.extend(renderer.render())
 
         return nodelist
@@ -622,7 +675,8 @@ class DocSimpleSectTypeSubRenderer(Renderer):
 
         nodelist = []
         for item in self.data_object.para:
-            renderer = self.renderer_factory.create_renderer(self.data_object, item)
+            context = self.context.create_child_context(item)
+            renderer = self.renderer_factory.create_renderer(context)
             nodelist.append(self.node_factory.paragraph("", "", *renderer.render()))
 
         term = self.node_factory.term("", "", *self.title())
@@ -635,7 +689,8 @@ class ParDocSimpleSectTypeSubRenderer(DocSimpleSectTypeSubRenderer):
 
     def title(self):
 
-        renderer = self.renderer_factory.create_renderer(self.data_object, self.data_object.title)
+        context = self.context.create_child_context(self.data_object.title)
+        renderer = self.renderer_factory.create_renderer(context)
 
         return [self.node_factory.strong( "", *renderer.render() )]
 
@@ -647,7 +702,8 @@ class DocTitleTypeSubRenderer(Renderer):
         nodelist = []
 
         for item in self.data_object.content_:
-            renderer = self.renderer_factory.create_renderer(self.data_object, item)
+            context = self.context.create_child_context(item)
+            renderer = self.renderer_factory.create_renderer(context)
             nodelist.extend(renderer.render())
 
         return nodelist
@@ -701,11 +757,12 @@ class ListingTypeSubRenderer(Renderer):
 
         lines = []
         nodelist = []
-        for i, entry in enumerate(self.data_object.codeline):
+        for i, item in enumerate(self.data_object.codeline):
             # Put new lines between the lines. There must be a more pythonic way of doing this
             if i:
                 nodelist.append(self.node_factory.Text("\n"))
-            renderer = self.renderer_factory.create_renderer(self.data_object, entry)
+            context = self.context.create_child_context(item)
+            renderer = self.renderer_factory.create_renderer(context)
             nodelist.extend(renderer.render())
 
         # Add blank string at the start otherwise for some reason it renders
@@ -723,8 +780,9 @@ class CodeLineTypeSubRenderer(Renderer):
     def render(self):
 
         nodelist = []
-        for entry in self.data_object.highlight:
-            renderer = self.renderer_factory.create_renderer(self.data_object, entry)
+        for item in self.data_object.highlight:
+            context = self.context.create_child_context(item)
+            renderer = self.renderer_factory.create_renderer(context)
             nodelist.extend(renderer.render())
 
         return nodelist
@@ -734,8 +792,9 @@ class HighlightTypeSubRenderer(Renderer):
     def render(self):
 
         nodelist = []
-        for entry in self.data_object.content_:
-            renderer = self.renderer_factory.create_renderer(self.data_object, entry)
+        for item in self.data_object.content_:
+            context = self.context.create_child_context(item)
+            renderer = self.renderer_factory.create_renderer(context)
             nodelist.extend(renderer.render())
 
         return nodelist
@@ -746,10 +805,11 @@ class TemplateParamListRenderer(Renderer):
 
         nodelist = []
 
-        for i, param in enumerate(self.data_object.param):
+        for i, item in enumerate(self.data_object.param):
             if i:
                 nodelist.append(self.node_factory.Text(", "))
-            renderer = self.renderer_factory.create_renderer(self.data_object, param)
+            context = self.context.create_child_context(item)
+            renderer = self.renderer_factory.create_renderer(context)
             nodelist.extend(renderer.render())
 
         return nodelist
@@ -777,7 +837,8 @@ class RefTypeSubRenderer(Renderer):
         # Read in the corresponding xml file and process
         file_data = self.compound_parser.parse(self.data_object.refid)
 
-        data_renderer = self.renderer_factory.create_renderer(self.data_object, file_data)
+        context = self.context.create_child_context(file_data)
+        data_renderer = self.renderer_factory.create_renderer(context)
         child_nodes = data_renderer.render()
 
         if not child_nodes:
@@ -792,7 +853,7 @@ class RefTypeSubRenderer(Renderer):
         return render_compound(
                 name,
                 file_data.compounddef.kind,
-                file_data,
+                context,
                 child_nodes,
                 self.renderer_factory,
                 self.node_factory,
@@ -847,7 +908,8 @@ class MixedContainerRenderer(Renderer):
 
     def render(self):
 
-        renderer = self.renderer_factory.create_renderer(self.data_object, self.data_object.getValue())
+        context = self.context.create_child_context(self.data_object.getValue())
+        renderer = self.renderer_factory.create_renderer(context)
         return renderer.render()
 
 
@@ -914,8 +976,9 @@ class DocListTypeSubRenderer(Renderer):
     def render(self):
         """ Render all the children depth-first. """
         nodelist = []
-        for entry in self.data_object.listitem:
-            renderer = self.renderer_factory.create_renderer(self.data_object, entry)
+        for item in self.data_object.listitem:
+            context = self.context.create_child_context(item)
+            renderer = self.renderer_factory.create_renderer(context)
             nodelist.extend(renderer.render())
 
         return nodelist
@@ -931,8 +994,9 @@ class DocListItemTypeSubRenderer(Renderer):
             Upon return expand the children node list into a docutils list-item.
         """
         nodelist = []
-        for entry in self.data_object.para:
-            renderer = self.renderer_factory.create_renderer(self.data_object, entry)
+        for item in self.data_object.para:
+            context = self.context.create_child_context(item)
+            renderer = self.renderer_factory.create_renderer(context)
             nodelist.extend(renderer.render())
 
         return [self.node_factory.list_item("", *nodelist)]
